@@ -34,6 +34,25 @@ def I(i, *k, enum=False, reverse=False, chunking=False, chunk_size=1):
     for j in loopyloop:
         yield j
 
+class Multiterator():
+    all = 0xA11
+    def __init__(self,):
+        self.iterations = {}
+    def __call__(self, name, *args, **kwargs):
+        self.iterations[name] = True
+        for m in I(*args, **kwargs):
+            if self.iterations[name]:
+                yield m
+            else:
+                break
+    def stop(self, name):
+        if name == Multiterator.all:
+            for i in self.iterations:
+                self.iterations[i] = False
+        else:
+            self.iterations[name] = False
+
+
 def IR(i, *args, **kwargs):
     return I(i, reverse=True, *args, **kwargs)
 
